@@ -10,6 +10,7 @@ test_that("accepts correct inputs", {
   expect_error(download_d1_data_pkg("test", "test"))
 })
 
+# EDI package test(s) ----
 test_that("accepts EDI data package", {
   # Takes too much time and add load on servers
   skip_on_cran()
@@ -21,11 +22,12 @@ test_that("accepts EDI data package", {
   unlink(output, recursive = TRUE)
 })
 
+# Arctic Data Center test(s) ----
 test_that("accepts Arctic Data Center data package", {
   # Takes too much time and add load on servers
   skip_on_cran()
   output <- download_d1_data_pkg(
-    meta_obj = 'doi:10.18739/A2DP3X',
+    meta_obj = 'doi:10.18739/A2B27PS44',
     path = tempdir()
     )
   expect_true(dir.exists(output[[1]]))
