@@ -6,7 +6,7 @@ test_that('data package report is not "data"', {
 
   output <- suppressMessages(
     get_pkg_pids(
-      pkg_doi = 'https://doi.org/10.6073/pasta/08abf45e6ef1585ad7ee1e00fb9d7dc1'
+      pkg_doi = 'doi:10.6073/pasta/25b39ca1bb9853a9ed3148ef64a2c1d5'
     )
   )
   expect_true(
